@@ -383,10 +383,20 @@ function __init(
         # TODO: deprecate once all docs are updated to the new form
         #@warn "passing Preconditioners at `init`/`solve` time is deprecated. Instead add a `precs` function to your algorithm."
     end
-    cacheval = init_cacheval(
-        alg, A, b, u0_, Pl, Pr, maxiters, abstol, reltol, init_cache_verb,
-        assumptions
-    )
+    # For DefaultLinearSolver, pass original prob.A so the A_backup field gets the
+    # correct type at construction time (prob.A may be e.g. WOperator while the
+    # converted A used for sub-caches may be a different concrete type).
+    cacheval = if alg isa DefaultLinearSolver
+        init_cacheval(
+            alg, A, b, u0_, Pl, Pr, maxiters, abstol, reltol, init_cache_verb,
+            assumptions, prob.A
+        )
+    else
+        init_cacheval(
+            alg, A, b, u0_, Pl, Pr, maxiters, abstol, reltol, init_cache_verb,
+            assumptions
+        )
+    end
     isfresh = true
     precsisfresh = false
     Tc = typeof(cacheval)
@@ -430,7 +440,7 @@ function SciMLBase.reinit!(
     cache.p = p
     cache.Pl = Pl
     cache.Pr = Pr
-    cache.isfresh = true
+    cache.isfresh = isfresh
     cache.precsisfresh = precsisfresh
     return nothing
 end
