@@ -1,5 +1,5 @@
 function __init__()
     IS_OPENBLAS[] = occursin("openblas", BLAS.get_config().loaded_libs[1].libname)
 
-    HAS_APPLE_ACCELERATE[] = __appleaccelerate_isavailable()
+    return HAS_APPLE_ACCELERATE[] = __appleaccelerate_isavailable()
 end
